// -*- mode: js2; indent-tabs-mode: nil; js2-basic-offset: 4 -*-

//    Window Title In Topbar
//    Puts the title of the focused window in the GNOME Shell top panel
//    Forked from https://extensions.gnome.org/extension/1496/focused-window-indicator/
//
//    ----------------------------------------------------------------------
//    Copyright © 2018  fthx
//    Copyright © 2021-2023  Philippe Troin (F-i-f on Github)
//    ----------------------------------------------------------------------
//
//    This program is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program.  If not, see <https://www.gnu.org/licenses/>.


import Clutter from 'gi://Clutter';
import Shell   from 'gi://Shell';
import St      from 'gi://St';
import * as Main   from 'resource:///org/gnome/shell/ui/main.js';
import {Extension} from 'resource:///org/gnome/shell/extensions/extension.js';

export default class WindowTitleInTopBarExtension extends Extension  {

    set_window_indicator() {
        if(!this.window)
            return;
        
        let windowTitle = this.window.get_title();
        this.label.set_text(windowTitle);
    }
    
    on_focus_window_notify() {
        // disconnect previous title notify signals
        if((this.windowTitleNotifyConnection)&&(this.window))
            this.window.disconnect(this.windowTitleNotifyConnection);
        
        // get current window
        this.window = global.display.get_focus_window();
        
        // if no focused window hide the app title
        if(!this.window) {
            this.label.set_text('');
            this.label.set({'visible':false});
            return;
            }
        
        // display the title
        this.label.set({'visible':true});
        this.windowTitleNotifyConnection = this.window.connect("notify::title", this.set_window_indicator.bind(this));
        this.set_window_indicator();
    }
    
    on_overview_enter() {
        this.label.set({'visible':false});
    }
        
    on_overview_exit() {
        this.label.set({'visible':true});
    }
    
    enable() {
        this.focusWindowNotifyConnection = null;
        this.windowTitleNotifyConnection = null;
        this.overviewEnterConnection = null;
        this.overviewExitConnection = null;
        this.window = null;

        this.focusedWindowIndicator = new St.Bin({style_class: 'panel-button'});
        this.label = new St.Label({y_align: Clutter.ActorAlign.CENTER});
        this.focusedWindowIndicator.set_child(this.label)

        Main.panel._leftBox.insert_child_at_index(this.focusedWindowIndicator, 3);
    
        this.focusWindowNotifyConnection = global.display.connect('notify::focus-window', this.on_focus_window_notify.bind(this));
        this.overviewEnterConnection = Main.overview.connect('showing', this.on_overview_enter.bind(this));
        this.overviewExitConnection = Main.overview.connect('hiding', this.on_overview_exit.bind(this));

        this.on_focus_window_notify();
    }
    
    disable() {
        global.display.disconnect(this.focusWindowNotifyConnection);
        Main.overview.disconnect(this.overviewEnterConnection);
        Main.overview.disconnect(this.overviewExitConnection);
        if((this.windowTitleNotifyConnection)&&(this.window))
            this.window.disconnect(this.windowTitleNotifyConnection);
        
        Main.panel._leftBox.remove_actor(this.focusedWindowIndicator)
        this.focusedWindowIndicator = null;
        this.label = null;
    }
}
